@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-11-28'; # DATE
-our $VERSION = '1.30'; # VERSION
+our $DATE = '2015-12-02'; # DATE
+our $VERSION = '1.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1151,7 +1151,9 @@ sub square { my %args=@_; [200, "OK", $args{num}**2] }
             {
                 name => 'config file',
                 before_all_tests => sub {
-                    write_text("$tempdir/prog.conf", <<'_');
+                    # old syntax, Perinci::CmdLine::Lite < 1.42. will not be
+                    # supported in the future
+                    write_text("$tempdir/prog-old.conf", <<'_');
 a=101
 b=201
 [subcommand1]
@@ -1164,6 +1166,20 @@ a=111
 d=201
 [subcommand1 profile=profile1]
 a=121
+_
+                    write_text("$tempdir/prog.conf", <<'_');
+a=101
+b=201
+[subcommand=subcommand1]
+a=102
+c=201
+[subcommand=subcommand2]
+a=103
+[profile=profile1]
+a=111
+d=201
+[subcommand=subcommand1 profile=profile1]
+a=121
 _
                     write_text("$tempdir/prog2.conf", <<'_');
 a=104
@@ -1299,6 +1315,25 @@ _
                         argv        => [qw/subcommand1/],
                         stdout_like => qr/^a=102\nb=201\nc=201\nd=\ne=$/,
                     },
+
+                    # this test will be removed in the future
+                    {
+                        tags        => ['config-file', 'subcommand'],
+                        name        => 'subcommand + --config-profile (old syntax)',
+                        gen_args => {
+                            url => '/Perinci/Examples/',
+                            subcommands => [
+                                'subcommand1:/Perinci/Examples/noop2',
+                            ],
+                            script_name => 'prog-old',
+                            read_config => 1,
+                            config_dirs => [$tempdir],
+                        },
+                        #inline_gen_args => {...},
+                        argv        => [qw/--config-profile=profile1 subcommand1/],
+                        stdout_like => qr/^a=121\nb=201\nc=201\nd=201\ne=$/,
+                    },
+
                     {
                         tags        => ['config-file', 'subcommand'],
                         name        => 'subcommand + --config-profile',
@@ -1368,7 +1403,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.30 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-11-28.
+This document describes version 1.31 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-12-02.
 
 =head1 SEE ALSO
 
